@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -148,7 +148,7 @@ function aggregate_color_form_save() {
 			$save1['color_template_id'] = 0;
 		}
 
-		$save1['name'] = form_input_validate(get_nfilter_request_var('name'), 'name', '', false, 3);
+		$save1['name'] = form_input_validate(get_filter_request_var('name', FILTER_SANITIZE_SPECIAL_CHARS), 'name', '', false, 3);
 
 		cacti_log('Saved ID: ' . $save1['color_template_id'] . ' Name: ' . $save1['name'], false, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
 
@@ -256,7 +256,7 @@ function aggregate_color_form_actions() {
 		} elseif (get_request_var('drp_action') == '3') { // sync
 			print "<tr>
 				<td class='textArea'>
-					<p>" . __n('Click \'Continue\' to Synchronize all Aggregate Graphs with the selected Color Template.', 'Click \'Continue\' to Syncrhonize all Aggregate Graphs with the selected Color Templates.', cacti_sizeof($color_array)) . "</p>
+					<p>" . __n('Click \'Continue\' to Synchronize all Aggregate Graphs with the selected Color Template.', 'Click \'Continue\' to Synchronize all Aggregate Graphs with the selected Color Templates.', cacti_sizeof($color_array)) . "</p>
 					<div class='itemlist'><ul>$color_list</ul></div></p>
 				</td>
 			</tr>";
@@ -518,26 +518,26 @@ function aggregate_color_template() {
 		$rows = get_request_var('rows');
 	}
 
-	form_start('color_templates.php', 'form_template');
-
 	html_start_box(__('Color Templates'), '100%', '', '3', 'center', 'color_templates.php?action=template_edit');
 
 	$filter_html = '<tr class="even">
 		<td>
-			<table class="filterTable">
-				<tr>
-					<td>
-						' . __('Search') . '
-					</td>
-					<td>
-						<input type="text" class="ui-state-default ui-corner-all" id="filter" size="25" value="' . html_escape_request_var('filter') . '">
-					</td>
-					<td>
-						' . __('Color Templates') . '
-					</td>
-					<td>
-						<select id="rows" onChange="applyFilter()">
-							<option value="-1" ';
+			<form id="form_template">
+				<table class="filterTable">
+					<tr>
+						<td>
+							' . __('Search') . '
+						</td>
+						<td>
+							<input type="text" class="ui-state-default ui-corner-all" id="filter" size="25" value="' . html_escape_request_var('filter') . '">
+						</td>
+						<td>
+							' . __('Color Templates') . '
+						</td>
+						<td>
+							<select id="rows" onChange="applyFilter()">
+								<option value="-1" ';
+
 	if (get_request_var('rows') == '-1') {
 		$filter_html .= 'selected';
 	}
@@ -555,21 +555,22 @@ function aggregate_color_template() {
 	}
 
 	$filter_html .= '			</select>
-					</td>
-					<td>
-						<span>
-							<input type="checkbox" id="has_graphs" ' . (get_request_var('has_graphs') == 'true' ? 'checked':'') . ' onChange="applyFilter()">
-							<label for="has_graphs">' . __('Has Graphs') . '</label>
-						</span>
-					</td>
-					<td>
-						<span>
-							<input type="button" class="ui-button ui-corner-all ui-widget" id="refresh" value="' . __esc('Go') . '">
-							<input type="button" class="ui-button ui-corner-all ui-widget" id="clear" value="' . __esc('Clear') . '">
-						</span>
-					</td>
-				</tr>
-			</table>
+							</td>
+							<td>
+								<span>
+									<input type="checkbox" id="has_graphs" ' . (get_request_var('has_graphs') == 'true' ? 'checked':'') . ' onChange="applyFilter()">
+									<label for="has_graphs">' . __('Has Graphs') . '</label>
+								</span>
+							</td>
+							<td>
+								<span>
+									<input type="submit" class="ui-button ui-corner-all ui-widget" id="go" value="' . __esc('Go') . '">
+									<input type="button" class="ui-button ui-corner-all ui-widget" id="clear" value="' . __esc('Clear') . '">
+								</span>
+							</td>
+						</tr>
+					</table>
+				</form>
 			</td>
 		</tr>';
 
@@ -577,8 +578,6 @@ function aggregate_color_template() {
 
 	html_end_box();
 
-	form_end();
-
 	/* form the 'where' clause for our main sql query */
 	$sql_where = '';
 	if (get_request_var('filter') != '') {
@@ -637,10 +636,25 @@ function aggregate_color_template() {
 	html_start_box('', '100%', '', '3', 'center', '');
 
 	$display_text = array(
-		'name'      => array(__('Template Title'), 'ASC'),
-		'nosort'    => array('display' => __('Deletable'), 'align' => 'right', 'tip' => __('Color Templates that are in use cannot be Deleted. In use is defined as being referenced by an Aggregate Template.')),
-		'graphs'    => array('display' => __('Graphs'), 'align' => 'right', 'sort' => 'DESC'),
-		'templates' => array('display' => __('Templates'), 'align' => 'right', 'sort' => 'DESC')
+		'name' => array(
+			'display' => __('Template Title'),
+			'sort'    => 'ASC'
+		),
+		'nosort' => array(
+			'display' => __('Deletable'),
+			'align' => 'right',
+			'tip' => __('Color Templates that are in use cannot be Deleted. In use is defined as being referenced by an Aggregate Template.')
+		),
+		'graphs'    => array(
+			'display' => __('Graphs'),
+			'align' => 'right',
+			'sort' => 'DESC'
+		),
+		'templates' => array(
+			'display' => __('Templates'),
+			'align' => 'right',
+			'sort' => 'DESC'
+		)
 	);
 
 	html_header_sort_checkbox($display_text, get_request_var('sort_column'), get_request_var('sort_direction'), false);
@@ -695,18 +709,10 @@ function aggregate_color_template() {
 	}
 
 	$(function() {
-		$('#refresh').click(function() {
-			applyFilter();
-		});
-
 		$('#clear').click(function() {
 			clearFilter();
 		});
 
-		$('#filter').change(function() {
-			applyFilter();
-		});
-
 		$('#form_template').submit(function(event) {
 			event.preventDefault();
 			applyFilter();
