@@ -28,7 +28,8 @@ include_once('./lib/poller.php');
 include_once('./lib/utility.php');
 
 $dq_actions = array(
-	1 => __('Delete')
+	1 => __('Delete'),
+	2 => __('Duplicate')
 );
 
 /* set default action */
@@ -123,7 +124,7 @@ function form_save() {
 		$save['hash']          = get_hash_data_query(get_nfilter_request_var('id'));
 		$save['name']          = form_input_validate(get_nfilter_request_var('name'), 'name', '', false, 3);
 		$save['description']   = form_input_validate(get_nfilter_request_var('description'), 'description', '', true, 3);
-		$save['xml_path']      = form_input_validate(get_nfilter_request_var('xml_path'), 'xml_path', '', false, 3);
+		$save['xml_path']      = form_input_validate(trim(get_nfilter_request_var('xml_path')), 'xml_path', '', false, 3);
 		$save['data_input_id'] = get_request_var('data_input_id');
 
 		// Detect changing input id
@@ -358,7 +359,13 @@ function form_actions() {
 				for ($i=0;($i<cacti_count($selected_items));$i++) {
 					 data_query_remove($selected_items[$i]);
 				}
+			} elseif (get_nfilter_request_var('drp_action') == '2') { /* duplicate */
+				for ($i=0;($i<cacti_count($selected_items));$i++) {
+					 data_query_duplicate($selected_items[$i], get_nfilter_request_var('name_format'));
+				}
 			}
+		} else {
+			raise_message(40);
 		}
 
 		header('Location: data_queries.php?header=false');
@@ -395,17 +402,29 @@ function form_actions() {
 
 	if (isset($dq_array) && cacti_sizeof($dq_array)) {
 		if (get_nfilter_request_var('drp_action') == '1') { /* delete */
-			$graphs = array();
-
 			print "<tr>
 				<td class='textArea' class='odd'>
-					<p>" . __n('Click \'Continue\' to delete the following Data Query.', 'Click \'Continue\' to delete following Data Queries.', cacti_sizeof($dq_array)) . "</p>
+					<p>" . __n('Click \'Continue\' to Delete the following Data Query.', 'Click \'Continue\' to Delete following Data Queries.', cacti_sizeof($dq_array)) . "</p>
 					<div class='itemlist'><ul>$dq_list</ul></div>
 				</td>
-			</tr>\n";
-		}
+			</tr>";
 
-		$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Delete Data Query', 'Delete Data Query', cacti_sizeof($dq_array)) . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Delete Data Query', 'Delete Data Queries', cacti_sizeof($dq_array)) . "'>";
+		} elseif (get_nfilter_request_var('drp_action') == '2') { /* duplicatie */
+			print "<tr>
+				<td class='textArea' class='odd'>
+					<p>" . __n('Click \'Continue\' to duplicate the following Data Query.', 'Click \'Continue\' to duplicate following Data Queries.', cacti_sizeof($dq_array)) . "</p>
+					<div class='itemlist'><ul>$dq_list</ul></div>
+					<p><strong>" . __('Name Format:'). "</strong><br>";
+
+			form_text_box('name_format', '<dataquery_name> (1)', '', '255', '30', 'text');
+
+			print "</p>
+                </td>
+            </tr>";
+
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Duplicate Data Query', 'Duplicate Data Queries', cacti_sizeof($dq_array)) . "'>";
+		}
 	} else {
 		raise_message(40);
 		header('Location: data_queries.php?header=false');
@@ -1423,7 +1442,7 @@ function data_query() {
 	$i = 0;
 	if (cacti_sizeof($snmp_queries)) {
 		foreach ($snmp_queries as $snmp_query) {
-			if ($snmp_query['graphs'] == 0 && $snmp_query['templates'] == 0) {
+			if ($snmp_query['graphs'] == 0) {
 				$disabled = false;
 			} else {
 				$disabled = true;
