@@ -137,6 +137,7 @@ $cacti_version_codes = array(
 	'1.2.22'  => '0103',
 	'1.2.23'  => '0103',
 	'1.2.24'  => '0103',
+	'1.2.25'  => '0103',
 );
 
 $messages = array(
@@ -827,6 +828,22 @@ $device_threads = array(
 	10 => __('%d Threads', 10)
 );
 
+$device_change_fields = array(
+	'preg_field' => array(
+		'/^snmp_/',
+		'/^ping_/'
+	),
+	'match_field' => array(
+		'poller_id',
+		'site_id',
+		'host_template_id',
+		'availability_method',
+		'device_threads',
+		'location',
+		'max_oids'
+	)
+);
+
 $cron_intervals = array(
 	60  => __('Every Minute'),
 	300 => __('Every %d Minutes', 5)
@@ -964,11 +981,11 @@ if ($config['poller_id'] == 1 || $config['connection'] == 'online') {
 	$menu = array(
 		__('Main Console') => array(
 			'index.php' => __('Console Page')
-			),
+		),
 		__('Create') => array(
 			'graphs_new.php' => __('New Graphs'),
 			'host.php?action=edit&create=true' => __('New Device')
-			),
+		),
 		__('Management') => array(
 			'host.php'             => __('Devices'),
 			'sites.php'            => __('Sites'),
@@ -976,49 +993,49 @@ if ($config['poller_id'] == 1 || $config['connection'] == 'online') {
 			'graphs.php'           => __('Graphs'),
 			'data_sources.php'     => __('Data Sources'),
 			'aggregate_graphs.php' => __('Aggregates'),
-			),
+		),
 		__('Data Collection') => array(
 			'pollers.php' => __('Data Collectors'),
 			'data_queries.php' => __('Data Queries'),
 			'data_input.php'   => __('Data Input Methods')
-			),
+		),
 		__('Templates') => array(
 			'host_templates.php'      => __('Device'),
 			'graph_templates.php'     => __('Graph'),
 			'data_templates.php'      => __('Data Source'),
 			'aggregate_templates.php' => __('Aggregate'),
 			'color_templates.php'     => __('Color')
-			),
+		),
 		__('Automation') => array(
 			'automation_networks.php'    => __('Networks'),
 			'automation_devices.php'     => __('Discovered Devices'),
 			'automation_templates.php'   => __('Device Rules'),
 			'automation_graph_rules.php' => __('Graph Rules'),
 			'automation_tree_rules.php'  => __('Tree Rules'),
-			'automation_snmp.php'        => __('SNMP Options'),
-			),
+		),
 		__('Presets') => array(
 			'data_source_profiles.php' => __('Data Profiles'),
+			'automation_snmp.php'      => __('SNMP'),
 			'cdef.php'                 => __('CDEFs'),
 			'vdef.php'                 => __('VDEFs'),
 			'color.php'                => __('Colors'),
-			'gprint_presets.php'       => __('GPRINTs')
-			),
+			'gprint_presets.php'       => __('GPRINTs'),
+		),
 		__('Import/Export') => array(
 			'templates_import.php' => __('Import Templates'),
 			'package_import.php'   => __('Import Packages'),
 			'templates_export.php' => __('Export Templates')
-			),
+		),
 		__('Configuration')  => array(
 			'settings.php'         => __('Settings'),
 			'user_admin.php'       => __('Users'),
 			'user_group_admin.php' => __('User Groups'),
 			'user_domains.php'     => __('User Domains')
-			),
+		),
 		__('Utilities') => array(
 			'utilities.php'  => __('System Utilities'),
 			'links.php'      => __('External Links'),
-			),
+		),
 		__('Troubleshooting') => array(
 			'data_debug.php' => __('Data Sources'),
 		)
@@ -1071,7 +1088,10 @@ $device_classes = array(
 	'loadbalancer' => __('Load Balancer'),
 	'switch'       => __('Network Switch'),
 	'router'       => __('Network Router'),
-	'firewall'     => __('Network Firewall'),
+	'nassan'       => __('NAS/SAN Related'),
+	'firewall'     => __('Network Firewalls'),
+	'power'        => __('Power Related PDUs/STS, etc.'),
+	'printer'      => __('Printer Related'),
 	'storage'      => __('Storage Related'),
 	'telephony'    => __('Telco Related'),
 	'webserver'    => __('Web Server Related'),
