@@ -143,12 +143,18 @@ function db_connect_real($device, $user, $pass, $db_name, $db_type = 'mysql', $p
 			if (strpos($ver, 'MariaDB') !== false) {
 				$srv = 'MariaDB';
 				$ver  = str_replace('-MariaDB', '', $ver);
+				$required_modes[] = 'NO_ENGINE_SUBSTITUTION';
 			} else {
 				$srv = 'MySQL';
-			}
 
-			if (version_compare('8.0.0', $ver, '<=')) {
-				$bad_modes[] = 'NO_AUTO_CREATE_USER';
+				if (version_compare('8.0.0', $ver, '<=')) {
+					$bad_modes[] = 'NO_AUTO_CREATE_USER';
+					$required_modes[] = 'NO_ENGINE_SUBSTITUTION';
+				}
+
+				if (version_compare('8.1.0', $ver, '<=')) {
+					$bad_modes[] = 'NO_ENGINE_SUBSTITUTION';
+				}
 			}
 
 			// Get rid of bad modes
@@ -163,7 +169,6 @@ function db_connect_real($device, $user, $pass, $db_name, $db_type = 'mysql', $p
 
 			// Add Required modes
 			$required_modes[] = 'ALLOW_INVALID_DATES';
-			$required_modes[] = 'NO_ENGINE_SUBSTITUTION';
 
 			foreach($required_modes as $mode) {
 				if (array_search($mode, $new_modes) === false) {
@@ -222,7 +227,7 @@ function db_connect_real($device, $user, $pass, $db_name, $db_type = 'mysql', $p
 	return false;
 }
 
-function db_check_reconnect($db_conn = false) {
+function db_check_reconnect($db_conn = false, $log = true) {
 	global $config, $database_details;
 
 	include($config['base_path'] . '/include/config.php');
@@ -261,7 +266,9 @@ function db_check_reconnect($db_conn = false) {
 	}
 
 	if ($version === false) {
-		syslog(LOG_ALERT, 'CACTI: Database Connection went away.  Attempting to reconnect!');
+		if ($log) {
+			syslog(LOG_ALERT, 'CACTI: Database Connection went away.  Attempting to reconnect!');
+		}
 
 		db_close();
 
@@ -1785,8 +1792,11 @@ function sql_save($array_items, $table_name, $key_cols = 'id', $autoinc = true,
 				}
 			} elseif (empty($value)) {
 				$array_items[$key] = 0;
-			} else {
+			} elseif (is_numeric($value)) {
 				$array_items[$key] = $value;
+			} else {
+				cacti_log('ERROR: Column: ' . $key . ' contains and invald value: ' . $value, false, 'DBCALL');
+				$array_items[$key] = 0;
 			}
 		} else {
 			$array_items[$key] = db_qstr($value);
