@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2022 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -29,9 +29,9 @@
 /* draw_edit_form - draws an html edit form
    @arg $array - an array that contains all of the information needed to draw
      the html form. see the arrays contained in include/global_settings.php
-     for the extact syntax of this array */
+     for the extract syntax of this array */
 function draw_edit_form($array) {
-	if (cacti_sizeof($array) > 0) {
+	if (cacti_sizeof($array)) {
 		foreach ($array as $top_branch => $top_children) {
 			if ($top_branch == 'config') {
 				$config_array = $top_children;
@@ -41,7 +41,7 @@ function draw_edit_form($array) {
 		}
 	}
 
-	if (cacti_sizeof($fields_array) > 0) {
+	if (cacti_sizeof($fields_array)) {
 		if (!isset($config_array['no_form_tag'])) {
 			print "<form class='cactiForm' method='post' autocomplete='off' action='" . ((isset($config_array['post_to'])) ? $config_array['post_to'] : get_current_page()) . "'" . ((isset($config_array['form_name'])) ? " name='" . $config_array['form_name'] . "'" : '') . ((isset($config_array['enctype'])) ? " enctype='" . $config_array['enctype'] . "'" : '') . ">\n";
 		}
@@ -122,6 +122,10 @@ function draw_edit_form($array) {
 
 			$i++;
 		}
+
+		if (isset($_SESSION['sess_error_fields'])) {
+			kill_session_var('sess_error_fields');
+		}
 	}
 }
 
@@ -350,9 +354,9 @@ function draw_edit_control($field_name, &$field_array) {
 		break;
 	case 'checkbox_group':
 		if (isset($field_array['type']) && $field_array['type'] == 'flex') {
-			print "</td></tr><tr><td><div id='${field_name}_group' class='checkboxgroup1 flexContainer'>" . PHP_EOL;
+			print "</td></tr><tr><td><div id='{$field_name}_group' class='checkboxgroup1 flexContainer'>" . PHP_EOL;
 		} else {
-			print "<div id='${field_name}_group' class='checkboxgroup1'>" . PHP_EOL;
+			print "<div id='{$field_name}_group' class='checkboxgroup1'>" . PHP_EOL;
 		}
 
 		foreach ($field_array['items'] as $check_name => $check_array) {
@@ -705,9 +709,9 @@ function form_hidden_box($form_name, $form_previous_value, $form_default_value,
      -- or --
      $array[0]["id"] = 43;
      $array[0]["name"] = "Red";
-   @arg $column_display - used to indentify the key to be used for display data. this
+   @arg $column_display - used to identify the key to be used for display data. this
      is only applicable if the array is formatted using the second method above
-   @arg $column_id - used to indentify the key to be used for id data. this
+   @arg $column_id - used to identify the key to be used for id data. this
      is only applicable if the array is formatted using the second method above
    @arg $form_previous_value - the current value of this form element
    @arg $form_none_entry - the name to use for a default 'none' element in the dropdown
@@ -856,7 +860,7 @@ function form_callback($form_name, $classic_sql, $column_display, $column_id, $c
 
 		$(function() {
 		    $('#<?php print $form_name;?>_input').autocomplete({
-		        source: '<?php print get_current_page();?>?action=<?php print $callback;?>',
+				source: '<?php print get_current_page();?>?action=<?php print $callback;?>',
 				autoFocus: true,
 				minLength: 0,
 				select: function(event,ui) {
@@ -1165,7 +1169,7 @@ function form_color_dropdown($form_name, $form_previous_value, $form_none_entry,
 		print "<option value='0'>$form_none_entry</option>";
 	}
 
-	if (cacti_sizeof($colors_list) > 0) {
+	if (cacti_sizeof($colors_list)) {
 		foreach ($colors_list as $color) {
 			if ($color['name'] == '') {
 				$display = __('Cacti Color (%s)', $color['hex']);
@@ -1173,7 +1177,7 @@ function form_color_dropdown($form_name, $form_previous_value, $form_none_entry,
 				$display = $color['name'] . ' (' . $color['hex'] . ')';
 			}
 
-			print "<option data-color='" . $color['hex'] . "' style='background-color: #" . $color['hex'] . ";' value='" . $color['id'] . "'";
+			print "<option data-color='" . html_escape($color['hex']) . "' style='background-color: #" . html_escape($color['hex']) . ";' value='" . $color['id'] . "'";
 
 			if ($form_previous_value == $color['id']) {
 				print ' selected';
@@ -1222,7 +1226,7 @@ function form_font_box($form_name, $form_previous_value, $form_default_value, $f
 		}
 	}
 
-	if ($form_previous_value == '') { # no data: defaults are used; everythings fine
+	if ($form_previous_value == '') { # no data: defaults are used; everything is fine
 		$extra_data = '';
 	} else {
 		/* verifying all possible pango font params is too complex to be tested here
@@ -1306,7 +1310,7 @@ function form_save_button($cancel_url, $force_type = '', $key_field = 'id', $aja
 	}
 
 	if ($force_type != 'import' && $force_type != 'export' && $force_type != 'save' && $force_type != 'close' && $cancel_url != '') {
-		$cancel_action = "<input type='button' class='ui-button ui-corner-all ui-widget' onClick='cactiReturnTo(\"" . html_escape($cancel_url, ENT_QUOTES) . "\")' value='" . $calt . "'>";
+		$cancel_action = "<input type='button' class='ui-button ui-corner-all ui-widget' onClick='cactiReturnTo(\"" . html_escape(sanitize_uri($cancel_url)) . "\")' value='" . $calt . "'>";
 	} else {
 		$cancel_action = '';
 	}
