@@ -1,26 +1,26 @@
 <?php
 /*
-   +-------------------------------------------------------------------------+
-   | Copyright (C) 2004-2021 The Cacti Group                                 |
-   |                                                                         |
-   | This program is free software; you can redistribute it and/or           |
-   | modify it under the terms of the GNU General Public License             |
-   | as published by the Free Software Foundation; either version 2          |
-   | of the License, or (at your option) any later version.                  |
-   |                                                                         |
-   | This program is snmpagent in the hope that it will be useful,           |
-   | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
-   | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
-   | GNU General Public License for more details.                            |
-   +-------------------------------------------------------------------------+
-   | Cacti: The Complete RRDtool-based Graphing Solution                     |
-   +-------------------------------------------------------------------------+
-   | This code is designed, written, and maintained by the Cacti Group. See  |
-   | about.php and/or the AUTHORS file for specific developer information.   |
-   +-------------------------------------------------------------------------+
-   | http://www.cacti.net/                                                   |
-   +-------------------------------------------------------------------------+
-*/
+ +-------------------------------------------------------------------------+
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
+ |                                                                         |
+ | This program is free software; you can redistribute it and/or           |
+ | modify it under the terms of the GNU General Public License             |
+ | as published by the Free Software Foundation; either version 2          |
+ | of the License, or (at your option) any later version.                  |
+ |                                                                         |
+ | This program is distributed in the hope that it will be useful,         |
+ | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
+ | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
+ | GNU General Public License for more details.                            |
+ +-------------------------------------------------------------------------+
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
+ +-------------------------------------------------------------------------+
+ | This code is designed, written, and maintained by the Cacti Group. See  |
+ | about.php and/or the AUTHORS file for specific developer information.   |
+ +-------------------------------------------------------------------------+
+ | http://www.cacti.net/                                                   |
+ +-------------------------------------------------------------------------+
+ */
 
 function snmpagent_enabled() {
 	return read_config_option('enable_snmp_agent') == 'on';
@@ -256,7 +256,7 @@ function snmpagent_device_action_bottom($data){
 				$mc->object('cactiApplLastUpdate')->set(time());
 				break;
 			case '5':
-				/* clear device statisitics */
+				/* clear device statistics */
 				$values = array(
 					'cactiStatsDeviceMinTime'      => '9.99999',
 					'cactiStatsDeviceMaxTime'      => '0',
@@ -413,7 +413,7 @@ function snmpagent_poller_bottom() {
 		$mc_device_stats = $mc->table('cactiStatsDeviceTable')->select(array('cactiStatsDeviceIndex','cactiStatsDeviceFailedPolls'));
 		if ($mc_device_stats && cacti_sizeof($mc_device_stats)>0) {
 			foreach($mc_device_stats as $mc_device_stat) {
-				if (isset($mc_device_stat['cactiStatsDeviceFailedPolls'])) {
+				if (isset($mc_device_stat['cactiStatsDeviceFailedPolls']) && isset($mc_device_stat['cactiStatsDeviceIndex'])) {
 					$mc_dfailed[$mc_device_stat['cactiStatsDeviceIndex']] = $mc_device_stat['cactiStatsDeviceFailedPolls'];
 				}
 			}
@@ -613,7 +613,7 @@ function snmpagent_cache_install() {
 	$mc->install($config['base_path'] . '/mibs/CACTI-BOOST-MIB');
 	snmpagent_cache_init();
 
-	/* call install routine of plugins supporting the SNMPagent */
+	/* call install routine of plugins supporting the SNMPAgent */
 	api_plugin_hook('snmpagent_cache_install');
 }
 
@@ -644,7 +644,7 @@ function snmpagent_cache_rebuilt(){
 }
 
 function snmpagent_cache_init(){
-	/* fill up the cache with a minimum of data data and ignore all values that
+	/* fill up the cache with a minimum of data and ignore all values that
 	   *  will be updated automatically at the bottom of the next poller run
 	*/
 	$mc = new MibCache();
@@ -875,7 +875,7 @@ function snmpagent_notification($notification, $mib, $varbinds, $severity = SNMP
 	$difference = array_diff(array_keys($registered_var_binds), array_keys($varbinds));
 
 	if (cacti_sizeof($difference) == 0) {
-		/* order the managers by message type to send out all notifications immmediately. Informs
+		/* order the managers by message type to send out all notifications immediately. Informs
 		   will take more processing time.
 		*/
 		$notification_managers = db_fetch_assoc_prepared('SELECT sm.*
